@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1000';
+our $VERSION = '0.1001';
 
 use Carp;
 use List::MoreUtils qw/ any first_index /;
@@ -192,7 +192,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1000
+version 0.1001
 
 =head1 SYNOPSIS
 
@@ -249,10 +249,15 @@ mode B<scale_name>.
 
 Note on which the scale is based.  Default: C<C>
 
+* Must be an uppercase letter either alone or followed by C<#> or C<b>.
+Double-sharp and double-flat keys are not allowed.
+
 =head2 scale_name
 
 Name of the scale.  Default: C<major>
 
+* Must be one of the lowercase names shown below.
+
 The diatonic mode names supported are:
 
   ionian / major
@@ -270,6 +275,8 @@ designations?
 
 Default: C<1>
 
+* Must be a Boolean value.
+
 If this is set to C<0>, single notes can be used to return the
 major/minor Roman numeral for the given diatonic mode B<scale_name>.
 
